@@ -7,7 +7,7 @@ use TAP::Formatter::JUnit::Session;
 use base qw(TAP::Formatter::Console);
 use Class::Field qw(field);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 field 'testsuites'  => [];
 
@@ -47,7 +47,12 @@ sub summary {
 sub xml {
     my $self = shift;
     unless ($self->{xml}) {
-        $self->{xml} = XML::Generator->new(':pretty', ':std', 'encoding'=>'UTF-8');
+        $self->{xml} = XML::Generator->new(
+            ':pretty',
+            ':std',
+            'escape'   => 'always,high-bit,even-entities',
+            'encoding' => 'UTF-8',
+        );
     }
     return $self->{xml};
 }
@@ -59,7 +64,12 @@ sub xml {
 sub xml_unescape {
     my $self = shift;
     unless ($self->{xml_unescape}) {
-        $self->{xml_unescape} = XML::Generator->new(':pretty', ':std', 'escape'=>'unescaped', 'encoding'=>'UTF-8');
+        $self->{xml_unescape} = XML::Generator->new(
+            ':pretty',
+            ':std',
+            'escape'   => 'unescaped',
+            'encoding' => 'UTF-8'
+        );
     }
     return $self->{xml_unescape};
 }
@@ -156,6 +166,8 @@ C<Test::Harness>; they became the basis for the unit tests here.
 Other thanks go out to those that have provided feedback, comments, or patches:
 
   Mark Aufflick
+  Joe McMahon
+  Michael Nachbaur
 
 =head1 COPYRIGHT
 
